@@ -19,6 +19,7 @@
 package cache
 
 import (
+	"context"
 	"encoding/json"
 	"fmt"
 	"strings"
@@ -26,6 +27,7 @@ import (
 
 	"go.uber.org/zap"
 	v1 "k8s.io/api/core/v1"
+	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/labels"
 	"k8s.io/client-go/tools/cache"
 	podutil "k8s.io/kubernetes/pkg/api/v1/pod"
@@ -39,7 +41,8 @@ import (
 	"github.com/apache/incubator-yunikorn-k8shim/pkg/common/utils"
 	"github.com/apache/incubator-yunikorn-k8shim/pkg/dispatcher"
 	"github.com/apache/incubator-yunikorn-k8shim/pkg/log"
-	plugin "github.com/apache/incubator-yunikorn-k8shim/pkg/plugin/predicates"
+	"github.com/apache/incubator-yunikorn-k8shim/pkg/plugin/predicates"
+	"github.com/apache/incubator-yunikorn-k8shim/pkg/plugin/support"
 	"github.com/apache/incubator-yunikorn-scheduler-interface/lib/go/si"
 )
 
@@ -49,7 +52,7 @@ type Context struct {
 	nodes          *schedulerNodes                // nodes
 	schedulerCache *schedulercache.SchedulerCache // external cache
 	apiProvider    client.APIProvider             // apis to interact with api-server, scheduler-core, etc
-	predictor      *plugin.Predictor              // K8s predicates
+	predManager    predicates.PredicateManager    // K8s predicates
 	lock           *sync.RWMutex                  // lock
 }
 
@@ -71,7 +74,14 @@ func NewContext(apis client.APIProvider) *Context {
 
 	// init the controllers and plugins (need the cache)
 	ctx.nodes = newSchedulerNodes(apis.GetAPIs().SchedulerAPI, ctx.schedulerCache)
-	ctx.predictor = plugin.NewPredictor(schedulercache.GetPluginArgs(), apis.IsTestingMode())
+
+	// create the predicate manager
+	if !apis.IsTestingMode() {
+		sharedLister := support.NewSharedLister(ctx.schedulerCache)
+		clientSet := apis.GetAPIs().KubeClient.GetClientSet()
+		informerFactory := apis.GetAPIs().InformerFactory
+		ctx.predManager = predicates.NewPredicateManager(support.NewFrameworkHandle(sharedLister, informerFactory, clientSet))
+	}
 
 	return ctx
 }
@@ -307,7 +317,7 @@ func (ctx *Context) deleteConfigMaps(obj interface{}) {
 func (ctx *Context) triggerReloadConfig() {
 	log.Logger().Info("trigger scheduler configuration reloading")
 	clusterId := ctx.apiProvider.GetAPIs().Conf.ClusterID
-	if err := ctx.apiProvider.GetAPIs().SchedulerAPI.ReloadConfiguration(clusterId); err != nil {
+	if err := ctx.apiProvider.GetAPIs().SchedulerAPI.UpdateConfiguration(clusterId); err != nil {
 		log.Logger().Error("reload configuration failed", zap.Error(err))
 	}
 }
@@ -315,7 +325,7 @@ func (ctx *Context) triggerReloadConfig() {
 // evaluate given predicates based on current context
 func (ctx *Context) IsPodFitNode(name, node string, allocate bool) error {
 	// simply skip if predicates are not enabled
-	if !ctx.predictor.Enabled() {
+	if ctx.apiProvider.IsTestingMode() {
 		return nil
 	}
 
@@ -324,8 +334,8 @@ func (ctx *Context) IsPodFitNode(name, node string, allocate bool) error {
 	if pod, ok := ctx.schedulerCache.GetPod(name); ok {
 		// if pod exists in cache, try to run predicates
 		if targetNode := ctx.schedulerCache.GetNode(node); targetNode != nil {
-			meta := ctx.predictor.GetPredicateMeta(pod, ctx.schedulerCache.GetNodesInfoMap())
-			return ctx.predictor.Predicates(pod, meta, targetNode, allocate)
+			_, err := ctx.predManager.Predicates(pod, targetNode, allocate)
+			return err
 		}
 	}
 	return fmt.Errorf("predicates were not running because pod or node was not found in cache")
@@ -346,7 +356,19 @@ func (ctx *Context) bindPodVolumes(pod *v1.Pod) error {
 				zap.String("podName", pod.Name))
 		} else {
 			log.Logger().Info("Binding Pod Volumes", zap.String("podName", pod.Name))
-			return ctx.apiProvider.GetAPIs().VolumeBinder.Binder.BindPodVolumes(assumedPod)
+			boundClaims, claimsToBind, _, err := ctx.apiProvider.GetAPIs().VolumeBinder.GetPodVolumes(assumedPod)
+			if err != nil {
+				return err
+			}
+			node, err := ctx.schedulerCache.GetNodeInfo(assumedPod.Spec.NodeName)
+			if err != nil {
+				return err
+			}
+			volumes, _, err := ctx.apiProvider.GetAPIs().VolumeBinder.FindPodVolumes(assumedPod, boundClaims, claimsToBind, node)
+			if err != nil {
+				return err
+			}
+			return ctx.apiProvider.GetAPIs().VolumeBinder.BindPodVolumes(assumedPod, volumes)
 		}
 	}
 	return nil
@@ -373,7 +395,15 @@ func (ctx *Context) AssumePod(name string, node string) error {
 			// volume builder might be null in UTs
 			if ctx.apiProvider.GetAPIs().VolumeBinder != nil {
 				var err error
-				allBound, err = ctx.apiProvider.GetAPIs().VolumeBinder.Binder.AssumePodVolumes(pod, node)
+				boundClaims, claimsToBind, _, err := ctx.apiProvider.GetAPIs().VolumeBinder.GetPodVolumes(assumedPod)
+				if err != nil {
+					return err
+				}
+				volumes, _, err := ctx.apiProvider.GetAPIs().VolumeBinder.FindPodVolumes(pod, boundClaims, claimsToBind, targetNode.Node())
+				if err != nil {
+					return err
+				}
+				allBound, err = ctx.apiProvider.GetAPIs().VolumeBinder.AssumePodVolumes(pod, node, volumes)
 				if err != nil {
 					return err
 				}
@@ -546,7 +576,7 @@ func (ctx *Context) RemoveApplication(appID string) error {
 		}
 		// send the update request to scheduler core
 		rr := common.CreateUpdateRequestForRemoveApplication(app.applicationID, app.partition)
-		if err := ctx.apiProvider.GetAPIs().SchedulerAPI.Update(&rr); err != nil {
+		if err := ctx.apiProvider.GetAPIs().SchedulerAPI.UpdateApplication(&rr); err != nil {
 			log.Logger().Error("failed to send remove application request to core", zap.Error(err))
 		}
 		delete(ctx.applications, appID)
@@ -686,7 +716,7 @@ func (ctx *Context) updatePodCondition(task *Task, podCondition *v1.PodCondition
 			if podutil.UpdatePodCondition(&task.pod.Status, podCondition) {
 				if !ctx.apiProvider.IsTestingMode() {
 					_, err := ctx.apiProvider.GetAPIs().KubeClient.GetClientSet().CoreV1().
-						Pods(task.pod.Namespace).UpdateStatus(task.pod)
+						Pods(task.pod.Namespace).UpdateStatus(context.Background(), task.pod, metav1.UpdateOptions{})
 					if err == nil {
 						return true
 					}
@@ -839,7 +869,7 @@ func (ctx *Context) SaveConfigmap(request *si.UpdateConfigurationRequest) *si.Up
 	newConf := ykconf.DeepCopy()
 	oldConfData := ykconf.Data["queues.yaml"]
 	newConf.Data = newConfData
-	_, err = ctx.apiProvider.GetAPIs().KubeClient.GetClientSet().CoreV1().ConfigMaps(ykconf.Namespace).Update(newConf)
+	_, err = ctx.apiProvider.GetAPIs().KubeClient.GetClientSet().CoreV1().ConfigMaps(ykconf.Namespace).Update(context.Background(), newConf, metav1.UpdateOptions{})
 	if err != nil {
 		return &si.UpdateConfigurationResponse{
 			Success: false,
